<?php
/*

EstrateCMS

EstrateCMS is a Content Management System for professional websites.

Copyright (C) 2004, 2005, Estrate, Rudolph Froger, The Netherlands
Website:        http://www.estrate.nl
Postal address: Estrate
                Oostsingel 57B
                2612HD Delft
                The Netherlands

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

A copy of the license should be in the file named LICENSE.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

 */

define( 'MODULE_CMSTEMPLATES', TRUE );

class cmstemplates
{
	function getPositions()
	{
		if( !strpos( CMS_TEMPLATES_POSITIONS, ',' ) === FALSE ) {
			return explode( ',', CMS_TEMPLATES_POSITIONS );
		} else {
			return array( CMS_TEMPLATES_POSITIONS );
		}
	}

	function loadfile( $file, $module = '' )
	{
		/* 
		   Load a template file and return it's content, unmodified
		   1. try files in user path, in case site specific files are available
		   2. try files in module path, in case module specific files are available
		   3. try files in cmstemplates path for generic templates
		*/
		$module = strtolower( $module );
		
		$file = strtolower( $file ).'.tpl';
		if($module=='cmstemplates')$module='';
		//if($file=='admin.tpl') echo CMS_CLIENT_PATH.'templates/'.(empty($module)?'':$module.'/').$file.'<br />';
		if( file_exists( CMS_CLIENT_PATH.'templates/'.(empty($module)?'':$module.'/').$file ) ) {
			$path = CMS_CLIENT_PATH.'templates/'.(empty($module)?'':$module.'/').'/'.$file;
		} 
		elseif( file_exists( CMS_CLIENT_PATH.'modules/'.$module.(empty($module)?'':'/').$file ) ) {
			$path = CMS_CLIENT_PATH.'modules/'.$module.(empty($module)?'':'/').$file;
		} 
		/*elseif( file_exists( CMS_CLIENT_PATH.'modules/'.$module.'/'.$file ) ) {
			$path = CMS_CLIENT_PATH.'modules/'.$module.'/'.$file;
		} */
		elseif( file_exists( CMS_LIB_PATH.$module.'/'.$file ) ) {
			$path = CMS_LIB_PATH.$module.'/'.$file;
		} elseif( file_exists( CMS_LIB_PATH.'cmstemplates/'.$file ) ) {
			$path = CMS_LIB_PATH.'cmstemplates/'.$file;
		} else {
			if(CMS_DEBUG>0) trigger_error('template '.$module.'/'.$file.' not found',E_USER_WARNING);
			return FALSE;
		}
		$fp = fopen( $path, 'r' );
		$size = filesize( $path );
		if( $fp && $size ) {
			$text = fread( $fp, $size );
			fclose( $fp );
			
			return $text; 
		} else {
			if(CMS_DEBUG>0) echo 'template '.$module.'/'.$file.' is empty.<br />';
			return FALSE;
		}

	}

	function parse( $text, $vars = FALSE, $preparse = false )
	{

		// {{example}} will be replaced by value in $vars['example']
		// [[example]] will be replaced by value in constant EXAMPLE
		// {{example}} will again be replaces by value in $vars['example'], for variables in constants
		if( is_array( $vars ) ) {
			foreach( $vars as $key => $value ) 
			{
				//$value = $vars[$key] = htmlspecialchars(htmlspecialchars_decode($value));
				if( !is_array( $value ) && !is_object( $value ) ) {
					$text = preg_replace( '/\{\{'.$key.'\}\}/i', $value, $text );
				} else {
					unset( $vars[$key] );
				}
			}
		}
		preg_match_all( '/\[\[([a-z0-9_-]+)\]\]/i', $text, $matches );
		foreach( $matches[1] as $value ) {
			$constant = strtoupper( $value );
			if( defined( $constant ) ) {
				$text = preg_replace( '/\[\['.$value.'\]\]/', constant( $constant ), $text );
			}
		}
		if( is_array( $vars ) && !strpos( $text, '{{' )===FALSE ) {
			foreach( $vars as $key => $value ) {
				$text = preg_replace( '/\{\{'.$key.'\}\}/i', $value, $text );
			}
		}
	
		if(!$preparse && CMS_DEBUG==0)
		{
		    $text = preg_replace( '/ [a-z0-9_-]+="\{\{[^\}]+\}\}"/i', '', $text );
			$text = preg_replace( '/\{\{[^\}]+\}\}/i', '', $text );
		}
		else 
		{
			$text = preg_replace( '/\{\{class\}\}/i', '', $text );
		}	
		//remove empty tags which may not empty
		$cannot_be_empty=array('colspan','rowspan','id');
		foreach( $cannot_be_empty as $value )
		{
			$text = preg_replace( '/ '.$value.'=""/i', '', $text );
		}
		
		
		
		return $text;
	}

	//function show( $file, $module = 'cmstemplates', $vars = FALSE )
	function show( $file, $module = '', $vars = FALSE )
	{
		
		if( $text = cmstemplates::loadfile( $file, $module ) ) {
			return cmstemplates::parse( $text, $vars );
		} else {
			return FALSE;
		}
	}

	function getStylesheet($mods=array(),$css)
	{
		
		$stylesheets=array();
		
		if($css && file_exists( CMS_CLIENT_PATH.CMS_ADMIN_STYLE_URL.$css.'.css' ) ) {
			$stylesheets[]= CMS_BASE_URL.CMS_ADMIN_STYLE_URL.$css.'.css';
		} 
		elseif( file_exists( CMS_CLIENT_PATH.CMS_ADMIN_STYLE_URL.CMS_CSS.'.css' ) ) {
			$stylesheets[]= CMS_BASE_URL.CMS_ADMIN_STYLE_URL.CMS_CSS.'.css';
		} 
		
		foreach( $mods as $key => $record )
		{
     		$path='';
     		if(strstr($key,'_'))
     		{
			$key =preg_replace('/(([a-z]+_)+)([a-z]+$)/','\\1/|\\3',$key);
     		list($path,$key)=explode('|',str_replace('_','',$key));
     		}
			if( file_exists( CMS_CLIENT_PATH.CMS_ADMIN_STYLE_URL.$key.'.css' ) ) 
			{
			$stylesheets[]= CMS_BASE_URL.CMS_ADMIN_STYLE_URL.$key.'.css';
			}	
			elseif( file_exists( CMS_CLIENT_PATH.$path.'modules/'.$key.'/'.$key.'.css' ) ) 
			{
			$stylesheets[]= CMS_BASE_URL.$path.'modules/'.$key.'/'.$key.'.css';
			}
			elseif( file_exists( CMS_LIB_PATH.$path.$key.'/'.$key.'.css' ) ) 
			{
			$stylesheets[]= CMS_BASE_URL.'index.php?css='.$path.$key.'/'.$key.'.css';
			}
		}	
		return $stylesheets;
	}
	
	function getJavascripts($mods=array(),$js)
	{
		
		$javascripts=array();
		if($js && file_exists( CMS_CLIENT_PATH.CMS_MODULES_JSCRIPTS_URL.$js.'.js' ) ) {
			$javascripts[]= CMS_BASE_URL.CMS_MODULES_JSCRIPTS_URL.$js.'.js';
		} 
		elseif( file_exists( CMS_CLIENT_PATH.CMS_MODULES_JSCRIPTS_URL.CMS_CSS.'.js' ) ) {
			$javascripts[]= CMS_BASE_URL.CMS_MODULES_JSCRIPTS_URL.CMS_CSS.'.js';
		} 

		foreach( $mods as $key => $record )
		{
     		$path='';
     		if(strstr($key,'_'))
     		{
			$key =preg_replace('/(([a-z]+_)+)([a-z]+$)/','\\1/|\\3',$key);
     		list($path,$key)=explode('|',str_replace('_','',$key));
     		}
			if( file_exists( CMS_CLIENT_PATH.CMS_MODULES_JSCRIPTS_URL.$key.'.js' ) ) 
			{
			$javascripts[]= CMS_BASE_URL.CMS_MODULES_JSCRIPTS_URL.$key.'.js';
			}	
			elseif( file_exists( CMS_CLIENT_PATH.$path.'modules/'.$key.'/'.$key.'.js' ) ) 
			{
			$javascripts[]= CMS_BASE_URL.$path.'modules/'.$key.'/'.$key.'.js';
			}
			elseif( file_exists( CMS_LIB_PATH.$path.$key.'/'.$key.'.js' ) ) 
			{
			$javascripts[]= CMS_BASE_URL.'index.php?js='.$path.$key.'/'.$key.'.js';
			}
		}	
		return $javascripts;
	}

	function getFavicon()
	{
		/* beter een favicon.ico zie: http://www.winterdrache.de/freeware/png2ico/favicon.html */
	
		if( file_exists( CMS_CLIENT_PATH.CMS_TEMPLATES_IMAGE_DIR.'favicon.png' ) ) {
			return CMS_BASE_URL.CMS_TEMPLATES_IMAGE_DIR.'favicon.png';
		} else {
			return CMS_BASE_URL.CMS_ADMIN_STYLE_URL.'favicon.png';
		}
	}

	function getDoctype()
	{
		if( CMS_DOCTYPE == 'xhtml1-strict' ) {
			return '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">';
		} else {
			return '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">';
		}
	}

	
	
	function returnmessage($message,$styleclass='message')
	{
		$templ = cmstemplates::loadfile( 'returnmessage', 'cmstemplates' );
		$vars['styleclass']=$styleclass;
		$vars['message']=$message;
		return cmstemplates::parse( $templ, $vars );
	}
}
?>