<?php
/*

EstrateCMS

EstrateCMS is a Content Management System for professional websites.

Copyright (C) 2004, 2005, Estrate, Rudolph Froger, The Netherlands
Website:        http://www.estrate.nl
Postal address: Estrate
                Oostsingel 57B
                2612HD Delft
                The Netherlands

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

A copy of the license should be in the file named LICENSE.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

// -Evil tags are removed, but all normal (X)HTML tags can stay
// -If MagicQuotes are on, quotes are stripped
// -All input gets trimmed!
function clean($input)
{
	if( is_array( $input ) ) {
		foreach( $input as $key=>$value ) {
			$input[ $key ] = clean( $value );
			}
	} else {
		$input = stripEvilTags( $input );
		$input = trim( $input );
		if (get_magic_quotes_gpc()) {
			$input = stripslashes($input);
		}
	}
	return $input;
}

function stripEvilTags( $input )
{
	//these tags are NEVER allowed in anything the user posts
	/*
	$eviltags = array( "<(/)?script[^>]*>", "<\?php", "\?>", "<%", "%>", "<(/)?link[^>]*>", "<(/)?(i)?frame[^>]*>", "<meta[^>]*>" );
	*/
	
	$eviltags = array( "<\?php", "\?>", "<%", "%>", "<(/)?link[^>]*>", "<meta[^>]*>" );
	foreach( $eviltags as $ereg ) {
		$input = eregi_replace( $ereg, "", $input );
	}
	return $input;
}

function cleanGlobals()
{
	//clean all input which may come from users
	if( isset( $_POST ) ) {
		$_POST 		= clean($_POST);
	}
	if( isset( $_SESSION ) ) {
		$_SESSION 	= clean($_SESSION);	//should we really clean this too? Session-vars stay on server
	}
	if( isset( $_GET ) ) {
		$_GET 		= clean($_GET);
	}
	if( isset( $_COOKIE ) ) {
		$_COOKIE	= clean($_COOKIE);
	}
}

function loadConfig( $file, $pk=0 )
{
	//EstrateIO config files use a '|' to seperate fields
	//pk tells which field should be the primary key, which becomes the key of the returned array
	//if pk=0 then no field will be used as primary key

	if( file_exists( $file ) ) {
		
		$handle = fopen( $file, 'r' );
		while( !feof( $handle ) ) {
			$line = fgets( $handle, 4096 );
			if( ! strpos( $line, '|' ) === FALSE ) {
				$tmp = explode( '|', trim($line) );
				if( $pk ) {
					$output[$tmp[$pk-1]] = $tmp;
				} else {
					$output[] = $tmp;
				}
			}
		}
		
		fclose( $handle );
		if( isset( $output ) ) {
			//var_dump($output);
			return $output;
		} else {
			return FALSE;
		}
	}
}

function WikiToXhtml($input) {
	//yet to fill
}

// SUC = Safe User Content = Content provided by users (incl evil users) with simple formatting
// It can be used by Forums, Weblogs, Guestbooks etc
// Newlines become HTML line-breaks
// Content between {} will become emphasized
// Content between [] will become strong
// URL's and e-mailaddresses become links
// Smileys become real images
function SUCToXhtml( $content, $links=true, $showsmileys=true, $removelinks=false)
{
	$result = nl2br( $content );
        
		$result = ereg_replace( "\{([^\}]+)\}", "<em>\\1</em>", $result );
        $result = ereg_replace( "\[([^]]+)\]", "<strong>\\1</strong>", $result );
        //$result = eregi_replace( "(www\.[^ ]+)", "http://\\1", $result );
        if($removelinks)
        {
        $result = preg_replace('/((http:\/\/)*(www\.[^ ]+))/e',' ',$result);
        $result = eregi_replace( "(http://([^ ^<]+)(/$*))", ' ', $result );
		$result = eregi_replace( '([_a-z0-9-]+)(\.[_a-z0-9-]+)*@([a-z0-9-]+)(\.[a-z0-9-]+)*(\.[a-z]{2,6})', ' ', $result );
        }	
        elseif($links)
        {
        $result = preg_replace('/((http:\/\/)*(www\.[^ ]+))/e',"cleanURL('\\1')",$result);
        $result = eregi_replace( "(http://([^ ^<]+)(/$*))", "<a href=\"\\1\">\\2</a>", $result );
		$result = eregi_replace( '([_a-z0-9-]+)(\.[_a-z0-9-]+)*@([a-z0-9-]+)(\.[a-z0-9-]+)*(\.[a-z]{2,6})', "<a href=\"mailto:\\0\">\\0</a>", $result );
        }
        
        if($showsmileys)
        {
		$smileys = smileys();
        $images = array_values( $smileys );
        foreach( $images as $value ) {
        	$htmlimages[] = '<img src="'.CMS_BASE_URL.CMS_SMILEYS_URL.$value.'.gif" alt="(smiley)" />';
        }
        $result = str_replace( array_keys( $smileys ), $htmlimages, $result );
        }
        return $result;
}

function smileys( )
{
        $smileys = array(
        ':-)'   => 'smile',
        ':-('   => 'sad',
        ':-/'   => 'doubt',
        ';-)'   => 'wink',
        '(>)'=> 'arrow',
        ':-D'   => 'lol',
        '>-('=> 'evil',
        ':-S'   => 'confused',
        ':-P'   => 'razz',
        '(!)'   => 'exclaim',
        'B-)'   => 'cool',
        '>-D'=> 'mad',
        ':-|'   => 'neutral',
        ':#)'   => 'redface',
        '(?)'   => 'question',
        '$-)'   => 'rolleyes',
        '>-)'=> 'badgrin',
        '=-('   => 'cry',
        ':-o'   => 'surprised',
        '(*)'   => 'idea',
        '|-D'   => 'biggrin',
        '8-O'   => 'shock',
        ':)'    => 'smile',
        ':('    => 'sad',
        ';)'    => 'wink'
        );
        return $smileys;
}

function ToXhtml($markup, $input) {
	if( $markup == 'wiki' ) {
		return WikiToXhtml( $input );
	} elseif( $markup == 'suc' ) {
		return SUCToXhtml( $input );
	} else {
		return $input;
	}
}

function inputDate( $name, $selected, $include_zero = FALSE,$year=array() )
{

	/* vervangen door form class ?!! */		require_once CMS_LIB_PATH.'cmstemplates/cmstemplatesadmin.php';
	$months = explode( ',', MONTHS );
	if( $selected && is_numeric( $selected ) ) {
		$value = getdate( $selected );
	} elseif( $selected ) {
		if($value = strtotime( $selected )) {
			$value = getdate( $value );
		} else {
			$value['year'] = '0';
			$value['mon'] = '0';
			$value['mday'] = '0';
		}
	} else {
		$value['year'] = '0';
		$value['mon'] = '0';
		$value['mday'] = '0';
	}

	//$year = '<input value="'.$value['year'].'" size="4" name="'.$name.'_year" />';
	if(empty($year))
	{
				if( $include_zero ) {
					$year[0] = '-';
				}
				$j=date('Y');
				for( $m = 1; $m<101; $m++ ) {
					$year[$j-100+$m] = $j-100+$m;
				}
	}

	$year =  cmstemplatesadmin::selectList( $name.'_year', $year, $value['year'] );

	
	
	if( $include_zero ) {
		$month[0] = '-';
	}
	for( $m = 1; $m<13; $m++ ) {
		$month[$m] = $months[$m];
	}

	$month =  cmstemplatesadmin::selectList( $name.'_month', $month, $value['mon'] );

	if( $include_zero ) {
		$day[0] = '-';
	}
	for( $d = 1; $d<32; $d++ ) {
		$day[$d] = $d;
	}
	$day = cmstemplatesadmin::selectList( $name.'_day', $day, $value['mday'] );

	if( CMS_CURRENT_LANGUAGE == 'nl' ) {
		return $day.' &mdash; '.$month.' &mdash; '.$year;
	} elseif( CMS_CURRENT_LANGUAGE == 'en' ) {
		return $month.' '.$day.', of '.$year;
	} else {
		//ISO format of dates
		return $year.' &mdash; '.$month.' &mdash; '.$day;
	}
}

function inputTime( $name, $selected, $interval = 5 )
{
	if( $selected && is_numeric( $selected ) ) {
		$value = getdate( $selected );
	} elseif( $selected ) {
		if($value = strtotime( $selected )) {
			$value = getdate( $value );
		} else {
			$value = getdate();
		}
	} else {
		$value = getdate();
	}
	
	for( $h = 0; $h<24; $h++ ) {
		$hours[$h] = $h;
	}
	$hours = cmstemplatesadmin::selectList( $name.'_hours', $hours, $value['hours'] );

	for( $m = 0; $m<60; $m=$m+$interval ) {
		$minutes[$m] = sprintf( "%02d", $m );
	}
	$minutes = cmstemplatesadmin::selectList( $name.'_minutes', $minutes, $value['minutes'] );

	return $hours.' : '.$minutes;	
}

function inputDateTime( $name, $selected, $include_zero = FALSE )
{
	return inputDate( $name, $selected, $include_zero ).'&nbsp;&nbsp;'.inputTime( $name, $selected );
}

function prevent($str) {
	$injections = array('/(\n+)/i',
	'/(\r+)/i',
	'/(\t+)/i',
	'/(%0A+)/i',
	'/(%0D+)/i',
	'/(%08+)/i',
	'/(%09+)/i'
	);
	$str= preg_replace($injections,'',$str);
	return $str;
}

function sendEmail( $to, $cc, $bcc, $from, $subject, $plaintext, $html='',$extrapars='')
{
	//$to should only contain the e-mailaddress(es), no names
	$h[]	= "From: $from";
	if( $cc )	$h[]	= "Cc: $cc";
	if( $bcc )	$h[]	= "Bcc: $bcc";
	
	/* check for mail injections */
	
	for ($i=0; $i<count($h); $i++)
	{
		$h[$i]=prevent($h[$i]);
	}	
	
	$plaintext = str_replace( "\r\n", "\n", $plaintext );
	$plaintext = str_replace( "\r", "\n", $plaintext );
	$plaintext = str_replace( "\n", "\r\n", $plaintext );
	$h[] 	= "X-Mailer: OpensourceCMS.eu";
	if( $html ) {
		$boundary = 'OpensourceCMS_'.rand(1000000,9999999).'_'.time().'_XX';
		$html = str_replace( "\r\n", "\n", $html );
		$html = str_replace( "\r", "\n", $html );
		$html = str_replace( "\n", "\r\n", $html );
		$h[]	= "Mime-Version: 1.0";
		$h[]	= 'Content-Type: multipart/alternative;';
		$h[]	= '  boundary="'.$boundary.'"';
		$h[]	= '';
		$h[]	= wordwrap( 'This message is in MIME format. Since your mail reader does not understand this format, some or all of this message may not be legible.', 72 );
		$h[]	= '';
		
		$h[]	= '--'.$boundary;
		$h[]	= 'Content-Type: text/plain; charset=iso-8859-15';
		$h[]	= 'Content-Transfer-Encoding: 7bit';
		$h[]	= '';
		if( $plaintext ) {
			$h[]	= wordwrap( $plaintext, 72 );
		} else {
			$tmp   = preg_replace('/(<a href="(mailto:)*([^"]+)"[^>]*>[^<]+<\/a>)/ms',"\\3",$html);
			$h[]	= wordwrap( strip_tags( $tmp ), 72 );
		}
		$h[]	= '';
		
		$h[]	= '--'.$boundary;
		$h[]	= 'Content-Type: text/html; charset=iso-8859-15';
		$h[]	= 'Content-Transfer-Encoding: 7bit';
		$h[]	= '';
		$h[]	= '<html><body>'.$html.'</body></html>';
		$h[]	= '';

		$h[]	= '--'.$boundary.'--';
		$h	= implode( "\r\n", $h );
		return mail( $to, $subject, '', $h,((!empty($extrapars) && !ini_get('safe_mode') )?$extrapars:null) );
	} else {
		$h[]	= "Mime-Version: 1.0";
		//$h[]	= 'Content-Type: text/plain; charset=US-ASCII';
		//$h[]	= 'Content-Type: text/plain; charset=UTF-8';
		$h[]	= 'Content-Type: text/plain; charset=iso-8859-15';
		//$h[]	= 'Content-Transfer-Encoding: quoted-printable';
		//$h[]	= 'Content-Transfer-Encoding: 8bit';
		$h[]	= 'Content-Transfer-Encoding: 7bit';
		//$h[]	= 'Content-Transfer-Encoding: BASE64';
		$m	= wordwrap( $plaintext, 72, "\r\n" );
		$h[]	= '';
		$h	= implode( "\r\n", $h );
		return mail( $to, $subject, $m, $h,((!empty($extrapars) && !ini_get('safe_mode') )?$extrapars:null));
	}
}

function getBrowser()
{
	//wiseguys = ilse, scooter = altavista, slurp = inktomi / yahoo, zyborg, grub = looksmart, jeeves =ask jeeves
	//mozilla should come last, many agents put "mozilla" in their ua strings
	$detection_strings = array( 'firefox', 'konqueror', 'opera', 'msie', 'safari', 'galeon',
		'lynx', 'camino', 'netscape', 'google', 'wiseguys', 'yahoo', 'scooter', 'slurp',
		'msnbot', 'lycos', 'zyborg', 'grub', 'jeeves', 'mozilla');
	$ua = strtolower( $_SERVER['HTTP_USER_AGENT'] );
	foreach( $detection_strings as $test ) {
		if( ! strpos( $ua, $test ) === FALSE ) {
			return $test;
		}
	}
	return 'other';
}

function getOS()
{
	$detection_strings = array( 'linux', 'mac', 'win', 'unix', 'freebsd', 'solaris', 'irix'	);
	$ua = strtolower( $_SERVER['HTTP_USER_AGENT'] );
	foreach( $detection_strings as $test ) {
		if( ! strpos( $ua, $test ) === FALSE ) {
			return $test;
		}
	}
	return 'other';
}

function getReferer()
{
	if(!isset($_SERVER['HTTP_REFERER']))return FALSE;
	$ref = strtolower( $_SERVER['HTTP_REFERER'] );
	if( strpos( $ref, CMS_DOMAIN ) === FALSE ) {
		return $ref;
	} else {
		return FALSE;
	}
}

function getIP()
{
	if( isset( $_SERVER["HTTP_X_FORWARDED_FOR"] ) && $_SERVER["HTTP_X_FORWARDED_FOR"] ) {
		$ip = $_SERVER["HTTP_X_FORWARDED_FOR"];
	} elseif( isset( $_SERVER["HTTP_CLIENT_IP"] ) && $_SERVER["HTTP_CLIENT_IP"] ) {
		$ip = $_SERVER["HTTP_CLIENT_IP"];
	} else {
		$ip = $_SERVER["REMOTE_ADDR"];
	}
	return $ip;
}

function getHostname( $ip )
{
	return strtolower( gethostbyaddr( $ip ) );
}

function getSecurityInfo()
{
	//get security info, return "tinytext" for logging securityinfo
	$ip = getIP();
	$msg[]	= 'ip:'.$ip.' host:'.getHostname( $ip );
	$msg[]	= date( "Y-m-d H:i:s T" );
	$msg[]  = 'ref:'.getReferer();
	$msg[]	= 'ua:'.$_SERVER['HTTP_USER_AGENT'];
	if( CMS_CURRENT_USER_ID ) {
		$msg[]  = 'user:'.CMS_CURRENT_USER_NAME;
	}
	$msg	= implode( "\n", $msg );
	return substr( $msg, 0, 255);
}


function checkemail_format($email)
{
	if( !eregi('^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-][a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z][a-z]+)$',$email ) )return false;
	else return true;
}


function cleanEmail( $in )
{
	ereg("([a-z0-9][a-z0-9_\.-]+@[a-z0-9][a-z0-9\.-]+\.[a-z]{2,4})", strtolower( $in ), $out);
	return $out[1];
}

function cleanPassword( $in )
{
	return ereg_replace( "[^a-zA-Z0-9\!\@\#\$\%\^\&\*\(\)\-\_\+\=\?]", "", $in );
}

function cleanURL( $in )
{
	$in = strtolower( trim( $in ) );
	if( $email = cleanEmail( $in ) ) {
		$out = 'mailto:'.$email;
	} elseif( substr( $in, 0, 7 ) == 'http://' ) {
		ereg( "(http://[a-z0-9/\.-]+\.[a-z]{2,4}(/[a-z0-9\./_-]*.*)?)", $in, $out );
		$out = $out[1];
	} elseif( substr( $in, 0, 4 ) == 'www.' ) {
		$in = 'http://'.$in;
		ereg( "(http://[a-z0-9/\.-]+\.[a-z]{2,4}(/[a-z0-9\./_-]*.*)?)", $in, $out );
		$out = $out[1];
	} else {
		ereg( "([a-z]+://[a-z0-9\.-]+\.[a-z]{2,4}(/[a-z0-9\./_-]*.*)?)", $in, $out );
		$out = $out[1];
	}
	return $out;
}

function cleanUsername( $in )
{
	return ereg_replace( "[^a-zA-Z0-9\._-]", "", strip_tags( $in ) );
}

function cleanDirectory( $dir )
{
	//makes sure it ends with a slash
	if( substr( $dir, -1 ) == '/' ) {
		return $dir;
	} else {
		return $dir.'/';
	}
}

function generatePassword( $strongness = 50 )
{
	//strongness ranges from 0-100, 0 generates a very easy password, 100 generated a very strong password
	$consts='bcdgklmnprst';
	$hard_consts='hqvwxz';
	$vowels='aeiou';
	$hard_vowels='jy';
	$numbers='0123456789';
	$symbols='!@#$%&*-_=+?';

	if($strongness > 60) {
		$consts .= $hard_consts;
		$vowels .= $hard_vowels;
	}

	for ($x=0; $x < 6; $x++) {
		$const[$x] = substr($consts,mt_rand(0,strlen($consts)-1),1);
		$vow[$x] = substr($vowels,mt_rand(0,strlen($vowels)-1),1);
		$number[$x] = substr($numbers,mt_rand(0,strlen($numbers)-1),1);
		$symbol[$x] = substr($symbols,mt_rand(0,strlen($symbols)-1),1);
	}

	if( $strongness < 25 ) {
		//8 character lowercase, will be more or less "pronounceable". Like: "ragtomen"
		$pw[0] = $const[0].$vow[0].$const[2].$const[1].$vow[1].$const[3].$vow[3].$const[4];
		//todo: check it against a dictionary to exclude real terms, strongness

	} elseif( $strongness <= 50 ) {
		//change to <= 13/03/2007 by bas@emailcommunications.nl
		//8 character lowercase, pronounceable parts, combined with numbers, like "gob45lok" or "harto746", or "6cungon7" or "29kidlo7"
		$pw[0] = $const[0].$vow[0].$const[2].$number[1].$number[0].$const[3].$vow[3].$const[4];
		$pw[1] = $const[0].$vow[0].$const[2].$const[1].$vow[1].$number[0].$number[1].$number[2];
		$pw[2] = $number[0].$const[0].$vow[0].$const[2].$const[1].$vow[1].$const[3].$number[1];
		$pw[3] = $number[0].$number[1].$const[0].$vow[0].$const[2].$const[1].$vow[1].$number[2];
	} elseif( $strongness < 75 ) {
		//8 character, pronounceable parts, partly uppercased combined with numbers and a symbol
		$pw[0] = $const[0].strtoupper($vow[0]).$const[2].$number[1].$number[0].strtoupper( $const[3] ).$vow[3].$const[4];
		$pw[1] = $const[0].strtoupper($vow[0]).strtoupper( $const[2]).$number[1].$number[0].$const[3].$vow[3].$const[4];
		$pw[2] = strtoupper( $const[0] ).$vow[0].$const[2].strtoupper( $const[1] ).$vow[1].$number[0].$number[1].$number[2];
		$pw[3] = $const[0].strtoupper( $vow[0] ).strtoupper( $const[2] ).$const[1].$vow[1].$number[0].$number[1].$number[2];
		$pw[4] = $number[0].$const[0].$vow[0].strtoupper( $const[2] ).strtoupper( $const[1] ).strtoupper( $vow[1] ).$const[3].$number[1];
		$pw[5] = $number[0].strtoupper( $const[0] ).$vow[0].$const[2].strtoupper( $const[1] ).$vow[1].$const[3].$number[1];
		$pw[6] = $number[0].$number[1].strtoupper( $const[0] ).$vow[0].strtoupper( $const[2] ).strtoupper( $const[1] ).$vow[1].$number[2];
		$pw[7] = $number[0].$number[1].$const[0].strtoupper( $vow[0] ).strtoupper( $const[2] ).$const[1].$vow[1].$number[2];
	} elseif( $strongness < 90 ) {
		//8 character string, completely random with lowercase, uppercase, symbols and numbers
		$pw[0] = array( $const[0], $const[1], strtoupper( $const[3] ), strtoupper( $const[4] ), $vow[0], $vow[1], strtoupper( $vow[2] ), strtoupper( $vow[3] ), $number[0], $number[1], $symbol[0], $symbol[1] );
		shuffle( $pw[0] );
		$pw[0] = implode( '', $pw[0] );
		$pw[0] = substr( $pw[0], 0, 8 );
	} else {
		//10 character string, completely random with lowercase, uppercase, symbols and numbers
		$pw[0] = array( $const[0], $const[1], $const[2], strtoupper( $const[3] ), strtoupper( $const[4] ), $vow[0], $vow[1], strtoupper( $vow[2] ), strtoupper( $vow[3] ), $number[0], $number[1], $symbol[0], $symbol[1] );
		shuffle( $pw[0] );
		$pw[0] = implode( '', $pw[0] );
		$pw[0] = substr( $pw[0], 0, 10 );
	}

	//choose a random password, from all generated passwords
	$pw = $pw[mt_rand(0,count($pw)-1)];

	return $pw;
}

function niceurl($url)
{
		//$url = strtolower( my_html_entity_encode($url) );
		//$url = strtolower( htmlentities( $url, ENT_NOQUOTES, 'UTF-8'  ) );
		//see: http://nl3.php.net/manual/en/ref.mbstring.php
		if(function_exists('mb_detect_order'))
        {
		mb_detect_order("UTF-8,ISO-8859-1");
		$url = strtolower( htmlentities(html_entity_decode($url,ENT_NOQUOTES, mb_detect_encoding($url)), ENT_NOQUOTES, mb_detect_encoding($url) ));
		}
		else
		{
			$url = strtolower( htmlentities(html_entity_decode($url,ENT_NOQUOTES), ENT_NOQUOTES));
		}
		$url = str_replace('\'s','',$url);
		$url = preg_replace("/&(.)(acute|cedil|circ|ring|tilde|uml);/", "$1", $url);
		$url = preg_replace("/([^a-z0-9]+)/", "_", html_entity_decode($url));
		$url = trim($url, "-");

		return $url;
}

function validate_email($email)
{

   // Create the syntactical validation regular expression
   $regexp = '^([_a-z0-9-]+)(\.[_a-z0-9-]+)*@([a-z0-9-]+)(\.[a-z0-9-]+)*(\.[a-z]{2,6})$';

   // Presume that the email is invalid
   $valid = false;

   // Validate the syntax
   if (preg_match('/'.$regexp.'/i', $email))
   {
      list($username,$domaintld) = split("@",$email);
      // Validate the domain
      if (getmxrr($domaintld,$mxrecords))
         $valid = true;
   } 

   return $valid;
}

function my_html_entity_decode($html)
{
	$decimalentities=include CMS_LIB_PATH.'cmsstructure/includes/decimalentities.php';
	$entitiescharacter=include CMS_LIB_PATH.'cmsstructure/includes/entitiescharacter.php';
	$html = strtr($html,$decimalentities);
	$html = strtr($html,$entitiescharacter);
	return $html;
}

function my_html_entity_encode($html)
{
    $entitiescharacter=include CMS_LIB_PATH.'cmsstructure/includes/entitiescharacter.php';
	unset($entitiescharacter['&amp;'],$entitiescharacter['&quot;']);
	foreach($entitiescharacter as $k=>$v)
	{
	$html = str_replace($v,$k,$html);
	}
	return $html;
}

function encodehtml($html)
{
        //echo $html.'<br />';
	    $html=my_html_entity_decode($html);// bugfix for php4
		//$html=html_entity_decode($html,ENT_NOQUOTES,'UTF-8');
        //echo $html.'<br />';
		$html=my_html_entity_encode($html);
        return str_replace(array('&gt;','&lt;'),array('>','<'),$html);
}

function lanuagepath($object)
{
	$class=get_class($object);
	if(strstr($class,'_'))list($voor,$class)=explode('_',$class);
	
	preg_match('/(.*)(admin$)/',$class,$matches);
	if (empty($matches)) return $class;
	else return str_replace('_','/',$matches[1].'/'.$matches[1].$matches[2]);
}

function checkcaptcha()
{

	if(empty($_POST['security_code']))return false;
	$code = 0;
if(isset($_SESSION['security_code']))
{
$code=$_SESSION['security_code'];
unset($_SESSION['security_code']);
}
if(($code == strtolower($_POST['security_code'])) && (!empty($code)) ) return true;
return false;
}

function fulldate($time,$showtime=1,$break=1)
{

	if(!$time)$time=time();
	$weekdays = explode(',',WEEKDAYS);
	$months = explode(',',MONTHS);
	$date = $weekdays[date('w',$time)].' ';
	$date .= date('j',$time).' ';
	$date .= $months[date('n',$time)].' ';
	$date .= date('Y',$time).' ';
	if($break)$date .='<br />';
	if($showtime)$date .= date('H:i:s',$time);
	return $date;
}	

function lcfirst($string)
{
	return strtolower(substr($string,0,1)) . substr($string,1);
}	

function fixhtml(&$vars)
{
	foreach($vars as $key=>$value)
	{
		if(is_string($value))
		{
		$enc=mb_detect_encoding($value,'UTF-8, ISO-8859-1');
		$vars[$key] = htmlentities(html_entity_decode($value,ENT_NOQUOTES,$enc),ENT_NOQUOTES,$enc);
		}
	}
}